﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection.Emit;
using System.Text;

using Xamarin.Forms;

namespace Selection
{
    public class SelectionPageCS : ContentPage
    {
        SfListView guessList;
        ViewModel viewModel;
        Grid headerGrid;
        Label resultViewNumLabel;
        Label resultViewGuessLabel;
        Label resultViewLastColumnLabel;

        public SelectionPageCS()
        {
            InitializeListView();
            Content = guessList;
        }

        private void InitializeListView()
        {
            viewModel = new ViewModel();
            guessList = new SfListView()
            {
                ItemsSource = viewModel.Items,
                IsEnabled = true,
                IsVisible = true,
                SelectionBackgroundColor = Color.FromHex("#ADD8E6"),
                BackgroundColor = Color.White,
                ItemTemplate = new DataTemplate(() => { return CreateItemTemplate(); }),
                VerticalOptions = LayoutOptions.FillAndExpand,
                HorizontalOptions = LayoutOptions.FillAndExpand,
                ItemSize = 120
            };

            // respond to double-tap when displaying color coded results
            guessList.SelectionMode = SelectionMode.Single;
            guessList.SelectionGesture = TouchGesture.DoubleTap;

            //guessList.SetBinding(SfListView.SelectedItemProperty,
            //                     new Binding(source: this, path: "newGuess", mode: BindingMode.TwoWay, converter: listConverter,
            //                                 converterParameter: guessList));

            guessList.HeaderTemplate = new DataTemplate(() =>
            {
                headerGrid = new Xamarin.Forms.Grid
                {
                    BackgroundColor = Color.White,
                    HorizontalOptions = LayoutOptions.FillAndExpand,
                    VerticalOptions = LayoutOptions.Fill,
                    IsVisible = true,
                    //IsEnabled = true,
                    ColumnSpacing = 2,
                    Padding = new Thickness(1, 6, 1, 6),

                    RowDefinitions = {
                        new RowDefinition { Height = new GridLength(1, GridUnitType.Star) },
                    },
                    ColumnDefinitions = {
                        new ColumnDefinition { Width = new GridLength(0.1, GridUnitType.Star) },
                        new ColumnDefinition { Width = new GridLength(0.55, GridUnitType.Star) },
                        new ColumnDefinition { Width = new GridLength(0.35, GridUnitType.Star) },
                    }
                };

                //Label lbl1, lbl2,lbl3;
                resultViewNumLabel = new Label();
                resultViewNumLabel.Text = "#";
                //resultViewNumLabel.Style = (Style)Resources["labelStyleMedium"];
                resultViewNumLabel.VerticalOptions = LayoutOptions.Fill;

                headerGrid.Children.Add(resultViewNumLabel, 0, 0);

                resultViewGuessLabel = new Label();
                resultViewGuessLabel.Text = "Guesses";
                //resultViewGuessLabel.Style = (Style)Resources["labelStyleMedium"];
                resultViewGuessLabel.VerticalOptions = LayoutOptions.Fill;

                headerGrid.Children.Add(resultViewGuessLabel, 1, 0);


                resultViewLastColumnLabel = new Label();
                //resultViewLastColumnLabel.Style = (Style)Resources["labelStyleMedium"];
                resultViewLastColumnLabel.HorizontalOptions = LayoutOptions.CenterAndExpand;
                resultViewLastColumnLabel.VerticalOptions = LayoutOptions.Fill;
                //resultViewLastColumnLabel.Text = this.resultViewLastColumnLabel.ToString();
                headerGrid.Children.Add(resultViewLastColumnLabel, 2, 0);

                return headerGrid;
            });
            guessList.IsStickyHeader = true;
            guessList.HeaderSize = 30;

        }

        private Grid CreateItemTemplate()
        {
            var maingrid = new Grid();
            var row0 = new RowDefinition { Height = new GridLength(1, GridUnitType.Star) };
            var row1 = new RowDefinition { Height = 1 };
            maingrid.RowDefinitions.Add(row0);
            maingrid.RowDefinitions.Add(row1);

            var frame = new Frame();
            frame.HasShadow = true;
            frame.BackgroundColor = Color.Transparent;
            frame.Padding = new Thickness(10);

            var grid = new Grid();
            var rowdefinition0 = new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) };
            var rowdefinition1 = new RowDefinition { Height = new GridLength(1, GridUnitType.Star) };
            var rowdefinition2 = new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) };
            grid.RowDefinitions.Add(rowdefinition0);
            grid.RowDefinitions.Add(rowdefinition1);
            grid.RowDefinitions.Add(rowdefinition2);

            var titlelabel = new Label();
            titlelabel.SetBinding(Label.TextProperty, new Binding("Title"));
            titlelabel.LineBreakMode = LineBreakMode.NoWrap;
            titlelabel.FontAttributes = FontAttributes.Bold;
            titlelabel.TextColor = Color.Black;

            var detailgrid = new Grid();
            var columndefinition0 = new ColumnDefinition { Width = new GridLength(1, GridUnitType.Star) };
            var columndefinition1 = new ColumnDefinition { Width = new GridLength(1, GridUnitType.Auto) };
            detailgrid.ColumnDefinitions.Add(columndefinition0);
            detailgrid.ColumnDefinitions.Add(columndefinition1);

            var descriptionLabel = new Label();
            descriptionLabel.SetBinding(Label.TextProperty, new Binding("Description"));
            descriptionLabel.TextColor = Color.Teal;

            var image = new Image();
            image.SetBinding(Image.SourceProperty, new Binding("Imagesource"));
            image.HeightRequest = 30;
            image.Margin = new Thickness(10, 0, 0, 10);

            var tagframe = new Frame();
            tagframe.BackgroundColor = Color.FromHex("#FFE7E8E9");
            tagframe.HorizontalOptions = LayoutOptions.Start;
            tagframe.VerticalOptions = LayoutOptions.End;
            tagframe.Padding = new Thickness(4, 2, 4, 2);

            var tagLabel = new Label();
            tagLabel.SetBinding(Label.TextProperty, new Binding("Tag"));
            tagLabel.LineBreakMode = LineBreakMode.NoWrap;
            tagLabel.FontSize = 10;
            tagLabel.TextColor = Color.Black;

            tagframe.Content = tagLabel;

            detailgrid.Children.Add(descriptionLabel);
            detailgrid.Children.Add(image, 1, 0);

            grid.Children.Add(titlelabel, 0, 0);
            grid.Children.Add(detailgrid, 0, 1);
            grid.Children.Add(tagframe, 0, 2);
            frame.Content = grid;

            var borderlayout = new Grid();
            borderlayout.HeightRequest = 1;
            borderlayout.BackgroundColor = Color.Gray;
            maingrid.Children.Add(frame);
            maingrid.Children.Add(borderlayout, 0, 1);
            return maingrid;
        }
    }
}
